@@ -54,9 +54,11 @@ link_public_api(Dictionary)
      dictionary_create_lang(const char * lang);
 link_public_api(Dictionary)
      dictionary_create_default_lang(void);
+link_public_api(const char *)
+     dictionary_get_lang(Dictionary);
 
 link_public_api(void)
-     dictionary_delete(Dictionary dict);
+     dictionary_delete(Dictionary);
 
 link_public_api(void)
      dictionary_set_data_dir(const char * path);
@@ -109,10 +111,6 @@ link_public_api(void)
      parse_options_set_max_null_count(Parse_Options opts, int null_count);
 link_public_api(int)
      parse_options_get_max_null_count(Parse_Options opts);
-link_public_api(void)
-     parse_options_set_null_block(Parse_Options opts, int null_block);
-link_public_api(int)
-     parse_options_get_null_block(Parse_Options opts);
 link_public_api(void)
      parse_options_set_islands_ok(Parse_Options opts, bool islands_ok);
 link_public_api(bool)
@@ -129,10 +127,6 @@ link_public_api(void)
      parse_options_set_max_memory(Parse_Options  opts, int mem);
 link_public_api(int)
      parse_options_get_max_memory(Parse_Options opts);
-link_public_api(void)
-     parse_options_set_max_sentence_length(Parse_Options  opts, int len);
-link_public_api(int)
-     parse_options_get_max_sentence_length(Parse_Options opts);
 link_public_api(void)
      parse_options_set_max_parse_time(Parse_Options  opts, int secs);
 link_public_api(int)
@@ -155,22 +149,10 @@ link_public_api(bool)
      parse_options_memory_exhausted(Parse_Options opts);
 link_public_api(bool)
      parse_options_resources_exhausted(Parse_Options opts);
-link_public_api(void)
-     parse_options_set_screen_width(Parse_Options opts, int val);
-link_public_api(int)
-     parse_options_get_screen_width(Parse_Options opts);
-link_public_api(void)
-     parse_options_set_allow_null(Parse_Options opts, bool val);
-link_public_api(bool)
-     parse_options_get_allow_null(Parse_Options opts);
 link_public_api(void)
      parse_options_set_use_cluster_disjuncts(Parse_Options opts, bool val);
 link_public_api(bool)
      parse_options_get_use_cluster_disjuncts(Parse_Options opts);
-link_public_api(void)
-     parse_options_set_display_walls(Parse_Options opts, bool val);
-link_public_api(bool)
-     parse_options_get_display_walls(Parse_Options opts);
 link_public_api(void)
      parse_options_set_all_short_connectors(Parse_Options opts, bool val);
 link_public_api(bool)
@@ -203,50 +185,10 @@ typedef enum
 } ConstituentDisplayStyle;
 
 
-link_public_api(void)
-     parse_options_set_batch_mode(Parse_Options opts, int val);
-link_public_api(int)
-     parse_options_get_batch_mode(Parse_Options opts);
-link_public_api(void)
-     parse_options_set_panic_mode(Parse_Options opts, int val);
-link_public_api(int)
-     parse_options_get_panic_mode(Parse_Options opts);
-link_public_api(void)
-     parse_options_set_display_on(Parse_Options opts, int val);
-link_public_api(int)
-     parse_options_get_display_on(Parse_Options opts);
-link_public_api(void)
-     parse_options_set_display_postscript(Parse_Options opts, int val);
-link_public_api(int)
-     parse_options_get_display_postscript(Parse_Options opts);
-link_public_api(void)
-     parse_options_set_display_constituents(Parse_Options opts, ConstituentDisplayStyle val);
-link_public_api(ConstituentDisplayStyle)
-     parse_options_get_display_constituents(Parse_Options opts);
-link_public_api(void)
-     parse_options_set_display_bad(Parse_Options opts, int val);
-link_public_api(int)
-     parse_options_get_display_bad(Parse_Options opts);
-link_public_api(void)
-     parse_options_set_display_disjuncts(Parse_Options opts, int val);
-link_public_api(int)
-     parse_options_get_display_disjuncts(Parse_Options opts);
-link_public_api(void)
-     parse_options_set_display_links(Parse_Options opts, int val);
-link_public_api(int)
-     parse_options_get_display_links(Parse_Options opts);
 link_public_api(void)
      parse_options_set_display_morphology(Parse_Options opts, int val);
 link_public_api(int)
      parse_options_get_display_morphology(Parse_Options opts);
-link_public_api(void)
-     parse_options_set_display_senses(Parse_Options opts, int val);
-link_public_api(int)
-     parse_options_get_display_senses(Parse_Options opts);
-link_public_api(void)
-     parse_options_set_echo_on(Parse_Options opts, int val);
-link_public_api(int)
-     parse_options_get_echo_on(Parse_Options opts);
 
 /**********************************************************************
  *
@@ -255,6 +197,7 @@ link_public_api(int)
  ***********************************************************************/
 
 typedef struct Sentence_s * Sentence;
+typedef size_t LinkageIdx;
 
 link_public_api(Sentence)
      sentence_create(const char *input_string, Dictionary dict);
@@ -275,11 +218,11 @@ link_public_api(int)
 link_public_api(int)
      sentence_num_linkages_post_processed(Sentence sent);
 link_public_api(int)
-     sentence_num_violations(Sentence sent, int i);
+     sentence_num_violations(Sentence sent, LinkageIdx linkage_num);
 link_public_api(double)
-     sentence_disjunct_cost(Sentence sent, int i);
+     sentence_disjunct_cost(Sentence sent, LinkageIdx linkage_num);
 link_public_api(int)
-     sentence_link_cost(Sentence sent, int i);
+     sentence_link_cost(Sentence sent, LinkageIdx linkage_num);
 
 /**********************************************************************
  *
@@ -292,51 +235,55 @@ link_public_api(int)
  ***********************************************************************/
 
 typedef struct Linkage_s * Linkage;
+typedef size_t WordIdx;
+typedef size_t LinkIdx;
 
 link_public_api(Linkage)
-     linkage_create(size_t index, Sentence sent, Parse_Options opts);
+     linkage_create(LinkageIdx linkage_num, Sentence sent, Parse_Options opts);
 link_public_api(void)
      linkage_delete(Linkage linkage);
-link_public_api(Sentence)
-     linkage_get_sentence(const Linkage linkage);
-link_public_api(int)
+link_public_api(size_t)
      linkage_get_num_words(const Linkage linkage);
 link_public_api(size_t)
      linkage_get_num_links(const Linkage linkage);
-link_public_api(size_t)
-     linkage_get_link_lword(const Linkage linkage, size_t index);
-link_public_api(size_t)
-     linkage_get_link_rword(const Linkage linkage, size_t index);
+link_public_api(WordIdx)
+     linkage_get_link_lword(const Linkage linkage, LinkIdx index);
+link_public_api(WordIdx)
+     linkage_get_link_rword(const Linkage linkage, LinkIdx index);
 link_public_api(int)
-     linkage_get_link_length(const Linkage linkage, int index);
+     linkage_get_link_length(const Linkage linkage, LinkIdx index);
 link_public_api(const char *)
-     linkage_get_link_label(const Linkage linkage, size_t index);
+     linkage_get_link_label(const Linkage linkage, LinkIdx index);
 link_public_api(const char *)
-     linkage_get_link_llabel(const Linkage linkage, size_t index);
+     linkage_get_link_llabel(const Linkage linkage, LinkIdx index);
 link_public_api(const char *)
-     linkage_get_link_rlabel(const Linkage linkage, size_t index);
+     linkage_get_link_rlabel(const Linkage linkage, LinkIdx index);
 link_public_api(int)
-     linkage_get_link_num_domains(const Linkage linkage, int index);
+     linkage_get_link_num_domains(const Linkage linkage, LinkIdx index);
 link_public_api(const char **)
-     linkage_get_link_domain_names(const Linkage linkage, int index);
+     linkage_get_link_domain_names(const Linkage linkage, LinkIdx index);
 link_public_api(const char **)
      linkage_get_words(const Linkage linkage);
 link_public_api(const char *)
-     linkage_get_disjunct_str(const Linkage linkage, int w);
+     linkage_get_disjunct_str(const Linkage linkage, WordIdx word_num);
 link_public_api(double)
-     linkage_get_disjunct_cost(const Linkage linkage, int w);
+     linkage_get_disjunct_cost(const Linkage linkage, WordIdx word_num);
 link_public_api(double)
-     linkage_get_disjunct_corpus_score(const Linkage linkage, int w);
+     linkage_get_disjunct_corpus_score(const Linkage linkage, WordIdx word_num);
 link_public_api(const char *)
-     linkage_get_word(const Linkage linkage, int w);
+     linkage_get_word(const Linkage linkage, WordIdx word_num);
 link_public_api(char *)
      linkage_print_constituent_tree(Linkage linkage, ConstituentDisplayStyle mode);
 link_public_api(void)
      linkage_free_constituent_tree_str(char *str);
 link_public_api(char *)
-     linkage_print_diagram(const Linkage linkage);
+     linkage_print_diagram(const Linkage linkage, bool display_walls, size_t screen_width);
 link_public_api(void)
      linkage_free_diagram(char * str);
+link_public_api(char *)
+     linkage_print_postscript(const Linkage linkage, bool display_walls, bool print_ps_header);
+link_public_api(void)
+     linkage_free_postscript(char * str);
 link_public_api(char *)
      linkage_print_disjuncts(const Linkage linkage);
 link_public_api(void)
@@ -345,10 +292,6 @@ link_public_api(char *)
      linkage_print_links_and_domains(const Linkage linkage);
 link_public_api(void)
      linkage_free_links_and_domains(char *str);
-link_public_api(char *)
-     linkage_print_postscript(Linkage linkage, int mode);
-link_public_api(void)
-     linkage_free_postscript(char * str);
 link_public_api(char *)
      linkage_print_pp_msgs(Linkage linkage);
 link_public_api(void)
@@ -375,6 +318,7 @@ link_public_api(const char *)
  *
  ***********************************************************************/
 
+/** Do not use in new code! */
 typedef struct Postprocessor_s PostProcessor;
 
 link_public_api(PostProcessor *)
@@ -382,7 +326,7 @@ link_public_api(PostProcessor *)
 link_public_api(void)
      post_process_close(PostProcessor *);
 link_public_api(void)
-     linkage_post_process(Linkage, PostProcessor *);
+     linkage_post_process(Linkage, PostProcessor *, Parse_Options);
 
 /**********************************************************************
  *
@@ -398,7 +342,7 @@ link_public_api(void)
      dict_display_word_info(Dictionary dict, const char *, Parse_Options opts);
 link_public_api(void)
      left_print_string(FILE* fp, const char *, const char *);
-link_public_api(int)
+link_public_api(bool)
      lg_expand_disjunct_list(Sentence sent);
 
 
@@ -426,9 +370,8 @@ link_public_api(void)
 
 /*******************************************************
  *
- * Obsolete functions -- do not use these in new code!
- * XXX TODO: These will all be removed, once the Russian dicts support
- * conjunctions; Russian is the last remaining user of these functions.
+ * Macros for marking obsolete functions -- but there aren't any,
+ * just right now.
  *
  ********************************************************/
 
@@ -444,91 +387,6 @@ link_public_api(void)
  #define MS_DEPRECATED
 #endif
 
-#ifdef USE_FAT_LINKAGES
-#pragma message("WARNING: Support for FAT linkages is going away!")
-#endif /* USE_FAT_LINKAGES */
-
-/* When fat links are gone, there's no union to compute. */
-MS_DEPRECATED link_public_api(int)
-     linkage_compute_union(Linkage linkage) GNUC_DEPRECATED;
-
-/* When fat links go away, all linkages are thin */
-MS_DEPRECATED link_public_api(int)
-     linkage_is_fat(const Linkage linkage) GNUC_DEPRECATED;
-
-/* When fat links go away, the number of sublinkages will always be one */
-MS_DEPRECATED link_public_api(int)
-     linkage_get_num_sublinkages(const Linkage linkage) GNUC_DEPRECATED;
-
-/* When fat links go away, the only valid sublinkage will be zero. */
-MS_DEPRECATED link_public_api(int)
-     linkage_set_current_sublinkage(Linkage linkage, int index) GNUC_DEPRECATED;
-
-/* When fat links go away, the only valid sublinkage will be zero. */
-MS_DEPRECATED link_public_api(int)
-     linkage_get_current_sublinkage(const Linkage linkage) GNUC_DEPRECATED;
-
-/* When fat links go away, all linkages are proper. */
-MS_DEPRECATED link_public_api(int)
-     linkage_is_improper(const Linkage linkage) GNUC_DEPRECATED;
-
-/* All linkages are canonical when there are no fat links. */
-MS_DEPRECATED link_public_api(int)
-     linkage_is_canonical(const Linkage linkage) GNUC_DEPRECATED;
-
-/* Not possible without fat links */
-MS_DEPRECATED link_public_api(int)
-     linkage_has_inconsistent_domains(const Linkage linkage) GNUC_DEPRECATED;
-
-/* and cost is always zero without fat links */
-MS_DEPRECATED link_public_api(int)
-     linkage_and_cost(const Linkage linkage) GNUC_DEPRECATED;
-
-/* All linkages are thin, when none are fat */
-MS_DEPRECATED link_public_api(int)
-     sentence_num_thin_linkages(Sentence sent) GNUC_DEPRECATED;
-
-/* Bogus/pointless when no fat links */
-MS_DEPRECATED link_public_api(int)
-     sentence_contains_conjunction(Sentence sent) GNUC_DEPRECATED;
-
-/* and cost is always zero without fat links */
-MS_DEPRECATED link_public_api(int)
-     sentence_and_cost(Sentence sent, int i) GNUC_DEPRECATED;
-
-/* Fat linkages will be going away "real soon now" */
-MS_DEPRECATED link_public_api(void)
-     parse_options_set_use_fat_links(Parse_Options opts, int use_fat_links) GNUC_DEPRECATED;
-MS_DEPRECATED link_public_api(int)
-     parse_options_get_use_fat_links(Parse_Options opts) GNUC_DEPRECATED;
-MS_DEPRECATED link_public_api(void)
-     parse_options_set_display_union(Parse_Options opts, int val) GNUC_DEPRECATED;
-MS_DEPRECATED link_public_api(int)
-     parse_options_get_display_union(Parse_Options opts) GNUC_DEPRECATED;
-
-/**********************************************************************
- *
- * Constituent node
- *
- ***********************************************************************/
-
-typedef struct CNode_s CNode;
-
-MS_DEPRECATED link_public_api(CNode *)
-     linkage_constituent_tree(Linkage linkage) GNUC_DEPRECATED;
-MS_DEPRECATED link_public_api(void)
-     linkage_free_constituent_tree(CNode * n) GNUC_DEPRECATED;
-MS_DEPRECATED link_public_api(const char *)
-     linkage_constituent_node_get_label(const CNode *n) GNUC_DEPRECATED;
-MS_DEPRECATED link_public_api(CNode *)
-     linkage_constituent_node_get_child(const CNode *n) GNUC_DEPRECATED;
-MS_DEPRECATED link_public_api(CNode *)
-     linkage_constituent_node_get_next(const CNode *n) GNUC_DEPRECATED;
-MS_DEPRECATED link_public_api(int)
-     linkage_constituent_node_get_start(const CNode *n) GNUC_DEPRECATED;
-MS_DEPRECATED link_public_api(int)
-     linkage_constituent_node_get_end(const CNode *n) GNUC_DEPRECATED;
-
 LINK_END_DECLS
 
 #endif
